import { ValueFieldModel } from '../../../index';
export interface DateFieldModel extends ValueFieldModel<Date, Date | string> {
    /**
     * Configures the time picker steps. E.g. 15 for 15 minute steps starting with every full hour.
     *
     * If 60 % resolution != 0, the minute steps starts every hour with 00 and rise in resolution steps.
     *
     * Default is 30 minutes.
     */
    timePickerResolution?: number;
    /**
     * Date to be used when setting a value "automatically", e.g. when the date picker is opened initially or when a date or time is entered and the other component has to be filled.
     * If no auto date is set (which is the default), the current date (with time part "00:00:00.000") is used.
     */
    autoDate?: Date | string;
    /**
     * Sets a list of allowed dates.
     * If the given array contains elements, the dates contained in the list can be chosen in the date-picker or entered manually in the date-field.
     * All other dates are disabled.
     * If the list is empty or null, all dates are available again.
     */
    allowedDates?: (string | Date)[];
    hasDate?: boolean;
    dateHasText?: boolean;
    dateFocused?: boolean;
    dateFormatPattern?: string;
    hasTime?: boolean;
    timeHasText?: boolean;
    timeFocused?: boolean;
    timeFormatPattern?: string;
    touchMode?: boolean;
}
//# sourceMappingURL=DateFieldModel.d.ts.map