import { ColorScheme, EnumObject, GridData, InitModelOf, LoadingSupport, ObjectOrModel, Resizable, TileEventMap, TileModel, TileMoveHandler, Widget } from '../index';
export type TileDisplayStyle = EnumObject<typeof Tile.DisplayStyle>;
export declare class Tile extends Widget implements TileModel {
    model: TileModel;
    eventMap: TileEventMap;
    self: Tile;
    animateBoundsChange: boolean;
    colorScheme: ColorScheme;
    displayStyle: TileDisplayStyle;
    gridData: GridData;
    gridDataHints: GridData;
    rowId: string;
    selected: boolean;
    selectable: boolean;
    movable: boolean;
    movableProducer: () => TileMoveHandler;
    resizable: boolean;
    resizableProducer: () => Resizable;
    plainText: string;
    constructor();
    static DisplayStyle: {
        DEFAULT: string;
        PLAIN: string;
    };
    protected _createLoadingSupport(): LoadingSupport;
    protected _init(model: InitModelOf<this>): void;
    protected _render(): void;
    protected _renderProperties(): void;
    protected _renderEnabled(): void;
    protected _postRender(): void;
    protected _renderDisplayStyle(): void;
    /** @see TileModel.gridDataHints */
    setGridDataHints(gridData: ObjectOrModel<GridData>): void;
    protected _setGridDataHints(gridData: ObjectOrModel<GridData>): void;
    /** @internal */
    _setGridData(gridData: ObjectOrModel<GridData>): void;
    /** @see TileModel.colorScheme */
    setColorScheme(colorScheme: ColorScheme | string): void;
    protected _setColorScheme(colorScheme: ColorScheme | string): void;
    protected _renderColorScheme(): void;
    /** @see TileModel.selected */
    setSelected(selected: boolean): void;
    protected _renderSelected(): void;
    /** @see TileModel.selectable */
    setSelectable(selectable: boolean): void;
    protected _setSelectable(selectable: boolean): void;
    protected _renderSelectable(): void;
    setMovableProducer(producer: () => TileMoveHandler): void;
    protected _renderMovableProducer(): void;
    setMovable(movable: boolean): void;
    protected _renderMovable(): void;
    protected _removeMovable(): void;
    setResizableProducer(producer: () => Resizable): void;
    protected _renderResizableProducer(): void;
    setResizable(resizable: boolean): void;
    protected _renderResizable(): void;
    protected _removeResizable(): void;
    setFilterAccepted(filterAccepted: boolean): void;
    get filterAccepted(): boolean;
    /** @internal */
    _renderVisible(): void;
    /**
     * Marks the element of this tile that is "focused" as the active descendant of the
     * container that has the "real" focus. You may override this to e.g. account for
     * custom navigation concepts in your tile, or if your tile should be announced
     * differently by screen readers.
     *
     * @param $container the focused container for which to mark the active descendant
     */
    markAsActiveDescendantFor($container: JQuery): void;
}
//# sourceMappingURL=Tile.d.ts.map